@@ -20,7 +20,7 @@
 
 
 """
-from __future__ import absolute_import
+
 
 
 import os
@@ -40,7 +40,7 @@ import bigmler.utils as u
 
 from bigmler.dispatcher import main_dispatcher
 from bigmler.options.analyze import ACCURACY, MINIMIZE_OPTIONS
-from bigmler.resources import ALL_FIELDS_QS
+from bigmler.resourcesapi.common import ALL_FIELDS_QS
 
 AVG_PREFIX = "average_%s"
 R_SQUARED = "r_squared"
@@ -99,11 +99,11 @@ DEFAULT_STALENESS = 5
 DEFAULT_KFOLDS = 5
 
 #subcommands
-SUBCOMMAND_LOG = u".bigmler_subcmd"
-SESSIONS_LOG = u"bigmler_sessions"
-FEATURES_LOG = u"features_sets.csv"
-NODES_LOG = u"nodes_sets.csv"
-CANDIDATES_LOG = u"random_candidate_sets.csv"
+SUBCOMMAND_LOG = ".bigmler_subcmd"
+SESSIONS_LOG = "bigmler_sessions"
+FEATURES_LOG = "features_sets.csv"
+NODES_LOG = "nodes_sets.csv"
+CANDIDATES_LOG = "random_candidate_sets.csv"
 
 #name max length
 NAME_MAX_LENGTH = 127
@@ -139,9 +139,6 @@ def retrieve_subcommands():
     """
     global subcommand_list
     subcommand_list = open(subcommand_file, u.open_mode("r")).readlines()
-    if not u.PYTHON3:
-        subcommand_list = [subcommand.decode(u.SYSTEM_ENCODING)
-                           for subcommand in subcommand_list]
     subcommand_list.reverse()
 
 
@@ -149,7 +146,7 @@ def rebuild_command(args):
     """Rebuilds a unicode command string prepared to be stored in a file
 
     """
-    return "%s\n" % (u" ".join(args)).replace("\\", "\\\\")
+    return "%s\n" % (" ".join(args)).replace("\\", "\\\\")
 
 
 def different_command(next_command, command):
@@ -238,23 +235,23 @@ def create_features_analysis(args, api, command_obj, resume=False):
 
     # showing the instruction to create the complete model with the
     # selected feature subset
-    bigmler_command = u'bigmler --dataset %s --model-fields="%s"' % ( \
+    bigmler_command = 'bigmler --dataset %s --model-fields="%s"' % ( \
         args.dataset, ",".join(model_fields))
     if args.number_of_models > 1:
-        bigmler_command = u"%s --number-of-models %s" % ( \
+        bigmler_command = "%s --number-of-models %s" % ( \
             bigmler_command, args.number_of_models)
     connection_args = command_obj.propagate([], connection_only=True)
-    bigmler_command = u"%s %s" % (bigmler_command, " ".join(connection_args))
-    message = (u'To create the final model with the entire dataset using '
-               u'the selected feature subset use:\n%s\n\n' %
+    bigmler_command = "%s %s" % (bigmler_command, " ".join(connection_args))
+    message = ('To create the final model with the entire dataset using '
+               'the selected feature subset use:\n%s\n\n' %
                bigmler_command)
     u.log_message(message, log_file=session_file, console=1)
     # showing the instruction to delete the user-given output-dir
-    bigmler_command = (u'bigmler delete --from-dir %s') % (
+    bigmler_command = ('bigmler delete --from-dir %s') % (
         output_dir)
-    bigmler_command = u"%s %s" % (bigmler_command, " ".join(connection_args))
-    message = (u'To delete all the resources generated by this analyze'
-               u' subcommand use:\n%s\n\n') % bigmler_command
+    bigmler_command = "%s %s" % (bigmler_command, " ".join(connection_args))
+    message = ('To delete all the resources generated by this analyze'
+               ' subcommand use:\n%s\n\n') % bigmler_command
     u.log_message(message, log_file=session_file, console=1)
 
 
@@ -280,17 +277,17 @@ def create_nodes_analysis(args, api, command_obj, resume=False):
         resume=resume)
     # showing the instruction to create the complete model with the
     # chosen node threshold
-    bigmler_command = (u'bigmler --dataset %s --node-threshold %s') % (
+    bigmler_command = ('bigmler --dataset %s --node-threshold %s') % (
         args.dataset, node_threshold)
-    message = (u'To create the final model with the entire dataset using '
-               u'the selected maximum number of nodes use:\n%s\n\n' %
+    message = ('To create the final model with the entire dataset using '
+               'the selected maximum number of nodes use:\n%s\n\n' %
                bigmler_command)
     u.log_message(message, log_file=session_file, console=1)
     # showing the instruction to delete the user-given output-dir
-    bigmler_command = (u'bigmler delete --from-dir %s') % (
+    bigmler_command = ('bigmler delete --from-dir %s') % (
         output_dir)
-    message = (u'To delete all the resources generated by this analyze'
-               u' subcommand use:\n%s\n\n') % bigmler_command
+    message = ('To delete all the resources generated by this analyze'
+               ' subcommand use:\n%s\n\n') % bigmler_command
     u.log_message(message, log_file=session_file, console=1)
 
 
@@ -350,7 +347,7 @@ def create_kfold_datasets_file(args, api, command_obj, resume=False):
         try:
             objective_id = fields.field_id(fields.objective_field)
             objective_name = fields.field_name(objective_id)
-        except ValueError, exc:
+        except ValueError as exc:
             sys.exit(exc)
         kfold_field_name = avoid_duplicates(DEFAULT_KFOLD_FIELD, fields)
         # create jsons to generate partial datasets
@@ -398,7 +395,7 @@ def avoid_duplicates(field_name, fields, affix="_"):
 
     """
     if any([field['name'] == field_name
-            for _, field in fields.fields.items()]):
+            for _, field in list(fields.fields.items())]):
         return avoid_duplicates("%s%s%s" % (affix, field_name, affix),
                                 fields, affix=affix)
     return field_name
@@ -489,8 +486,8 @@ def create_kfold_evaluations(datasets_file, args, command_obj,
     """
     global subcommand_list
     output_dir = os.path.normpath(
-        u.check_dir(os.path.join(u"%s%s" % (args.output_dir, counter),
-                                 u"evaluation.json")))
+        u.check_dir(os.path.join("%s%s" % (args.output_dir, counter),
+                                 "evaluation.json")))
     model_fields = args.model_fields
     name_suffix = "_subset_%s" % counter
     name_max_length = NAME_MAX_LENGTH - len(name_suffix)
@@ -582,7 +579,7 @@ def best_first_search(datasets_file, api, args, command_obj,
     try:
         with open(datasets_file, u.open_mode("r")) as datasets_handler:
             dataset_id = datasets_handler.readline().strip()
-    except IOError, exc:
+    except IOError as exc:
         sys.exit("Could not read the generated datasets file: %s" %
                  str(exc))
     try:
@@ -601,7 +598,7 @@ def best_first_search(datasets_file, api, args, command_obj,
         excluded_ids = [fields.field_id(feature) for
                         feature in excluded_features]
         objective_id = fields.field_id(objective_name)
-    except ValueError, exc:
+    except ValueError as exc:
         sys.exit(exc)
     field_ids = [field_id for field_id in fields.preferred_fields()
                  if field_id != objective_id and
@@ -631,7 +628,7 @@ def best_first_search(datasets_file, api, args, command_obj,
             state_fields = [fields.field_name(field_ids[index])
                             for (index, in_set) in enumerate(state)
                             if in_set]
-        except ValueError, exc:
+        except ValueError as exc:
             sys.exit(exc)
         closed_list.append(features_set)
         open_list.remove(features_set)
@@ -664,7 +661,7 @@ def best_first_search(datasets_file, api, args, command_obj,
                     input_fields = [fields.field_name(field_id)
                                     for (i, field_id)
                                     in enumerate(field_ids) if child[i]]
-                except ValueError, exc:
+                except ValueError as exc:
                     sys.exit(exc)
                 # create models and evaluation with input_fields
                 args.model_fields = args.args_separator.join(input_fields)
@@ -680,22 +677,22 @@ def best_first_search(datasets_file, api, args, command_obj,
     try:
         best_features = [fields.field_name(field_ids[i]) for (i, score)
                          in enumerate(best_state) if score]
-    except ValueError, exc:
+    except ValueError as exc:
         sys.exit(exc)
-    message = (u'The best feature subset is: %s \n'
-               % u", ".join(best_features))
+    message = ('The best feature subset is: %s \n'
+               % ", ".join(best_features))
     u.log_message(message, log_file=session_file, console=1)
     if metric in PERCENT_EVAL_METRICS:
-        message = (u'%s = %0.2f%%\n' % (metric.capitalize(),
+        message = ('%s = %0.2f%%\n' % (metric.capitalize(),
                                         (best_metric_value * 100)))
     else:
-        message = (u'%s = %f\n' % (metric.capitalize(), best_metric_value))
+        message = ('%s = %f\n' % (metric.capitalize(), best_metric_value))
     u.log_message(message, log_file=session_file, console=1)
     output_dir = os.path.normpath(u.check_dir(datasets_file))
     if args.predictions_csv:
         resume = create_prediction_dataset(output_dir, "kfold%s" % best_counter,
                                            args, resume)
-    message = (u'Evaluated %d/%d feature subsets\n\n' %
+    message = ('Evaluated %d/%d feature subsets\n\n' %
                ((len(open_list) + len(closed_list) - 1),
                 2 ** len(field_ids) - 1))
     u.log_message(message, log_file=session_file, console=1)
@@ -861,7 +858,7 @@ def create_node_th_evaluations(datasets_file, args, command_obj,
     """
     global subcommand_list
     output_dir = os.path.normpath(u.check_dir(
-        os.path.join(u"%s%s" % (args.output_dir, node_threshold),
+        os.path.join("%s%s" % (args.output_dir, node_threshold),
                      "evaluation.json")))
     command = COMMANDS["node_threshold"] % (
         datasets_file, node_threshold, output_dir)
@@ -898,7 +895,7 @@ def default_candidates_limits(args, fields):
 
     """
     args.min_candidates = DEFAULT_MIN_CANDIDATES
-    args.max_candidates = len(fields.preferred_fields().keys())
+    args.max_candidates = len(list(fields.preferred_fields().keys()))
 
 
 def create_candidates_analysis(args, api, command_obj, resume=False):
@@ -924,18 +921,18 @@ def create_candidates_analysis(args, api, command_obj, resume=False):
         resume=resume)
     # showing the instruction to create the complete model with the
     # chosen random candidates number
-    bigmler_command = (u'bigmler --dataset %s --number-of-models %s'
-                       u' --randomize --random-candidates %s') % ( \
+    bigmler_command = ('bigmler --dataset %s --number-of-models %s'
+                       ' --randomize --random-candidates %s') % ( \
         args.dataset, args.number_of_models, random_candidates)
-    message = (u'To create the final ensemble with the entire dataset using '
-               u'the selected number of random candidates use:\n%s\n\n' %
+    message = ('To create the final ensemble with the entire dataset using '
+               'the selected number of random candidates use:\n%s\n\n' %
                bigmler_command)
     u.log_message(message, log_file=session_file, console=1)
     # showing the instruction to delete the user-given output-dir
-    bigmler_command = (u'bigmler delete --from-dir %s') % (
+    bigmler_command = ('bigmler delete --from-dir %s') % (
         output_dir)
-    message = (u'To delete all the resources generated by this analyze'
-               u' subcommand use:\n%s\n\n') % bigmler_command
+    message = ('To delete all the resources generated by this analyze'
+               ' subcommand use:\n%s\n\n') % bigmler_command
     u.log_message(message, log_file=session_file, console=1)
 
 
@@ -1048,7 +1045,7 @@ def create_candidates_evaluations(datasets_file, args, command_obj,
     """
     global subcommand_list
     output_dir = os.path.normpath(u.check_dir(
-        os.path.join(u"%s%s" % (args.output_dir, random_candidates),
+        os.path.join("%s%s" % (args.output_dir, random_candidates),
                      "evaluation.json")))
     command = COMMANDS["random_candidates"] % (
         datasets_file, random_candidates, output_dir)
