@@ -17,24 +17,27 @@
 """BigMLer - anomaly subcommand processing dispatching
 
 """
-from __future__ import absolute_import
+
 
 import sys
 import os
-import shutil
 
 import bigml.api
 
 from bigml.anomaly import Anomaly
 
 import bigmler.utils as u
-import bigmler.resources as r
+import bigmler.resourcesapi.common as r
+import bigmler.resourcesapi.anomalies as ra
 import bigmler.pre_model_steps as pms
 import bigmler.processing.args as a
 import bigmler.processing.anomalies as pa
 import bigmler.processing.sources as ps
 import bigmler.processing.datasets as pd
 
+from bigmler.resourcesapi.datasets import set_basic_dataset_args
+from bigmler.resourcesapi.batch_anomaly_scores import \
+    set_batch_anomaly_score_args
 from bigmler.defaults import DEFAULTS_FILE
 from bigmler.anomaly_score import anomaly_score, remote_anomaly_score
 from bigmler.reports import clear_reports, upload_reports
@@ -42,12 +45,12 @@ from bigmler.command import get_context
 from bigmler.dispatcher import SESSIONS_LOG, clear_log_files, get_test_dataset
 from bigmler.options.anomaly import ANOMALIES_IN
 
-COMMAND_LOG = u".bigmler_anomaly"
-DIRS_LOG = u".bigmler_anomaly_dir_stack"
+COMMAND_LOG = ".bigmler_anomaly"
+DIRS_LOG = ".bigmler_anomaly_dir_stack"
 LOG_FILES = [COMMAND_LOG, DIRS_LOG, u.NEW_DIRS_LOG]
 MINIMUM_MODEL = "full=false"
 EXCLUDE_TREES = "exclude=trees"
-DEFAULT_OUTPUT = u"anomaly_scores.csv"
+DEFAULT_OUTPUT = "anomaly_scores.csv"
 
 SETTINGS = {
     "command_log": COMMAND_LOG,
@@ -66,8 +69,8 @@ def anomaly_dispatcher(args=sys.argv[1:]):
     if "--clear-logs" in args:
         clear_log_files(LOG_FILES)
 
-    command_args, command, api, session_file, resume = get_context(args,
-                                                                   SETTINGS)
+    command_args, _, api, session_file, resume = get_context(args,
+                                                             SETTINGS)
     # Selects the action to perform
     if (a.has_train(command_args) or a.has_test(command_args) or
             command_args.score or
@@ -110,7 +113,7 @@ def compute_output(api, args):
                  " to generate the new dataset from it.")
 
     path = u.check_dir(output)
-    session_file = u"%s%s%s" % (path, os.sep, SESSIONS_LOG)
+    session_file = "%s%s%s" % (path, os.sep, SESSIONS_LOG)
     csv_properties = {}
     # If logging is required set the file for logging
     log = None
@@ -165,11 +168,11 @@ def compute_output(api, args):
             if args.shared_flag and r.shared_changed(args.shared, anomaly):
                 anomaly_args.update(shared=args.shared)
             if args.public_anomaly:
-                anomaly_args.update(r.set_publish_anomaly_args(args))
+                anomaly_args.update(ra.set_publish_anomaly_args(args))
             if anomaly_args:
-                anomaly = r.update_anomaly(anomaly, anomaly_args, args,
-                                           api=api, path=path,
-                                           session_file=session_file)
+                anomaly = ra.update_anomaly(anomaly, anomaly_args, args,
+                                            api=api, path=path,
+                                            session_file=session_file)
                 anomalies[0] = anomaly
 
     # We get the fields of the anomaly detector if we haven't got
@@ -214,7 +217,7 @@ def compute_output(api, args):
                 test_source = api.check_resource(test_source_id)
             if test_dataset is None:
                 # create test dataset from test source
-                dataset_args = r.set_basic_dataset_args(args, name=test_name)
+                dataset_args = set_basic_dataset_args(args, name=test_name)
                 test_dataset, resume = pd.alternative_dataset_processing(
                     test_source, "test", dataset_args, api, args,
                     resume, session_file=session_file, path=path, log=log)
@@ -223,7 +226,7 @@ def compute_output(api, args):
                 test_dataset = api.check_resource(test_dataset_id)
             test_fields = pd.get_fields_structure(test_dataset,
                                                   csv_properties)
-            batch_anomaly_score_args = r.set_batch_anomaly_score_args(
+            batch_anomaly_score_args = set_batch_anomaly_score_args(
                 args, fields=fields,
                 dataset_fields=test_fields)
 
