@@ -41,7 +41,7 @@ python bigmler.py \
     --no-test-header
 
 """
-from __future__ import absolute_import
+
 
 import sys
 
@@ -51,8 +51,6 @@ from bigmler.parser import SUBCOMMANDS
 from bigmler.utils import BIGML_SYS_ENCODING
 
 
-PYTHON3 = sys.version_info[0] == 3
-
 def check_delete_option(args):
     """Checks if the --delete option (to be deprecated) is used and changes
        its syntax to the corresponding subcommand
@@ -79,8 +77,6 @@ def main(args=sys.argv[1:]):
             new_args = args
         # checks if the old --delete syntax is used
         new_args = check_delete_option(new_args)
-        if not PYTHON3:
-            new_args = [arg.decode(BIGML_SYS_ENCODING) for arg in new_args]
 
         subcommand = new_args[0].lower().strip("\n")
         if subcommand == "logistic-regression":
@@ -99,7 +95,7 @@ def main(args=sys.argv[1:]):
         subcommands = SUBCOMMANDS
         subcommands.sort()
         subcommands_text = "\n\n  ".join(["bigmler %s --help" % subcommand
-                                            for subcommand in subcommands])
+                                          for subcommand in subcommands])
         sys.exit("BigMLer used with no arguments.\n\nCheck:"
                  "\n\n  %s \n\nfor a list of options" % subcommands_text)
 
