@@ -16,23 +16,22 @@
 """Centroid auxiliary functions
 
 """
-from __future__ import absolute_import
+
 
 
 import sys
 
 import bigml.api
 
-import bigmler.utils as u
-import bigmler.checkpoint as c
-
-
 from bigml.cluster import Cluster
 from bigml.io import UnicodeWriter
 
+import bigmler.utils as u
+import bigmler.checkpoint as c
+
 from bigmler.tst_reader import TstReader as TestReader
-from bigmler.resources import NORMAL_FORMAT, FULL_FORMAT
-from bigmler.resources import create_batch_centroid
+from bigmler.resourcesapi.common import NORMAL_FORMAT, FULL_FORMAT
+from bigmler.resourcesapi.batch_centroids import create_batch_centroid
 
 # symbol used in failing centroid predictions
 NO_CENTROID = "-"
@@ -64,8 +63,8 @@ def use_prediction_headers(prediction_headers, output, test_reader,
                              fields.fields_columns]
 
         if args.prediction_fields is not None:
-            prediction_fields = map(str.strip,
-                                    args.prediction_fields.split(','))
+            prediction_fields = list(map(str.strip,
+                                    args.prediction_fields.split(',')))
             # Filter input_headers adding only those chosen by the user
             number_of_headers = len(input_headers)
             for index in range(0, number_of_headers):
