@@ -17,32 +17,36 @@
 """BigMLer - cluster subcommand processing dispatching
 
 """
-from __future__ import absolute_import
+
 
 import sys
 import os
-import shutil
 
 import bigml.api
 import bigmler.utils as u
-import bigmler.resources as r
+import bigmler.resourcesapi.common as r
+import bigmler.resourcesapi.clusters as rcl
+import bigmler.resourcesapi.batch_centroids as rbc
 import bigmler.pre_model_steps as pms
 import bigmler.processing.args as a
 import bigmler.processing.clusters as pc
 import bigmler.processing.sources as ps
 import bigmler.processing.datasets as pd
 
+from bigmler.resourcesapi.datasets import create_dataset, \
+    set_basic_dataset_args
+from bigmler.resourcesapi.models import create_model
 from bigmler.defaults import DEFAULTS_FILE
 from bigmler.centroid import centroid, remote_centroid
 from bigmler.reports import clear_reports, upload_reports
 from bigmler.command import get_context
 from bigmler.dispatcher import SESSIONS_LOG, clear_log_files, get_test_dataset
 
-COMMAND_LOG = u".bigmler_cluster"
-DIRS_LOG = u".bigmler_cluster_dir_stack"
+COMMAND_LOG = ".bigmler_cluster"
+DIRS_LOG = ".bigmler_cluster_dir_stack"
 LOG_FILES = [COMMAND_LOG, DIRS_LOG, u.NEW_DIRS_LOG]
 MINIMUM_MODEL = "full=false"
-DEFAULT_OUTPUT = u"centroids.csv"
+DEFAULT_OUTPUT = "centroids.csv"
 
 SETTINGS = {
     "command_log": COMMAND_LOG,
@@ -61,8 +65,7 @@ def cluster_dispatcher(args=sys.argv[1:]):
     if "--clear-logs" in args:
         clear_log_files(LOG_FILES)
 
-    command_args, command, api, session_file, resume = get_context(args,
-                                                                   SETTINGS)
+    command_args, _, api, session_file, resume = get_context(args, SETTINGS)
 
     # Selects the action to perform
     if (a.has_train(command_args) or a.has_test(command_args)
@@ -105,7 +108,7 @@ def compute_output(api, args):
                  " to generate the new dataset from it.")
 
     path = u.check_dir(output)
-    session_file = u"%s%s%s" % (path, os.sep, SESSIONS_LOG)
+    session_file = "%s%s%s" % (path, os.sep, SESSIONS_LOG)
     csv_properties = {}
     # If logging is required set the file for logging
     log = None
@@ -141,7 +144,7 @@ def compute_output(api, args):
 
     # We update the cluster's public state if needed
     if cluster:
-        if isinstance(cluster, basestring):
+        if isinstance(cluster, str):
             if args.cluster_datasets is None and not a.has_test(args):
                 query_string = MINIMUM_MODEL
             else:
@@ -155,11 +158,11 @@ def compute_output(api, args):
             if args.shared_flag and r.shared_changed(args.shared, cluster):
                 cluster_args.update(shared=args.shared)
             if args.public_cluster:
-                cluster_args.update(r.set_publish_cluster_args(args))
+                cluster_args.update(rcl.set_publish_cluster_args(args))
             if cluster_args:
-                cluster = r.update_cluster(cluster, cluster_args, args,
-                                           api=api, path=path,
-                                           session_file=session_file)
+                cluster = rcl.update_cluster(cluster, cluster_args, args,
+                                             api=api, path=path,
+                                             session_file=session_file)
                 clusters[0] = cluster
 
     # We get the fields of the cluster if we haven't got
@@ -192,7 +195,7 @@ def compute_output(api, args):
                 test_source = api.check_resource(test_source_id)
             if test_dataset is None:
                 # create test dataset from test source
-                dataset_args = r.set_basic_dataset_args(args, name=test_name)
+                dataset_args = set_basic_dataset_args(args, name=test_name)
                 test_dataset, resume = pd.alternative_dataset_processing(
                     test_source, "test", dataset_args, api, args,
                     resume, session_file=session_file, path=path, log=log)
@@ -201,7 +204,7 @@ def compute_output(api, args):
                 test_dataset = api.check_resource(test_dataset_id)
             test_fields = pd.get_fields_structure(test_dataset,
                                                   csv_properties)
-            batch_centroid_args = r.set_batch_centroid_args(
+            batch_centroid_args = rbc.set_batch_centroid_args(
                 args, fields=fields,
                 dataset_fields=test_fields)
 
@@ -219,7 +222,7 @@ def compute_output(api, args):
                      for centroid in centroids_info}
         cluster_datasets = cluster['object']['cluster_datasets']
         if args.cluster_datasets == '':
-            centroid_ids = centroids.values()
+            centroid_ids = list(centroids.values())
         else:
             centroid_ids = [centroids[cluster_name] for cluster_name in
                             args.cluster_datasets_
@@ -228,9 +231,9 @@ def compute_output(api, args):
 
         for centroid_id in centroid_ids:
             dataset_args = {'centroid': centroid_id}
-            r.create_dataset(cluster, dataset_args, args, api=api, path=path,
-                             session_file=session_file, log=log,
-                             dataset_type='cluster')
+            create_dataset(cluster, dataset_args, args, api=api, path=path,
+                           session_file=session_file, log=log,
+                           dataset_type='cluster')
 
     if cluster and args.cluster_models is not None:
         cluster = api.check_resource(cluster)
@@ -239,7 +242,7 @@ def compute_output(api, args):
                      for centroid in centroids_info}
         models = cluster['object']['cluster_models']
         if args.cluster_models == '':
-            centroid_ids = centroids.values()
+            centroid_ids = list(centroids.values())
         else:
             centroid_ids = [centroids[cluster_name] for cluster_name in
                             args.cluster_models_
@@ -247,9 +250,9 @@ def compute_output(api, args):
 
         for centroid_id in centroid_ids:
             model_args = {'centroid': centroid_id}
-            r.create_model(cluster, model_args, args, api=api, path=path,
-                           session_file=session_file, log=log,
-                           model_type='cluster')
+            create_model(cluster, model_args, args, api=api, path=path,
+                         session_file=session_file, log=log,
+                         model_type='cluster')
 
     if fields and args.export_fields:
         fields.summary_csv(os.path.join(path, args.export_fields))
