@@ -16,7 +16,7 @@
 """Logistic regression prediction auxiliary functions
 
 """
-from __future__ import absolute_import
+
 
 
 import sys
@@ -30,8 +30,7 @@ import bigmler.utils as u
 import bigmler.checkpoint as c
 
 from bigmler.tst_reader import TstReader as TestReader
-from bigmler.resources import NORMAL_FORMAT, FULL_FORMAT
-from bigmler.resources import create_batch_prediction
+from bigmler.resourcesapi.batch_predictions import create_batch_prediction
 from bigmler.prediction import use_prediction_headers
 from bigmler.lrprediction import write_prediction
 
