@@ -17,21 +17,23 @@
 """BigMLer - logistic regression subcommand processing dispatching
 
 """
-from __future__ import absolute_import
+
 
 import sys
 import os
-import shutil
 
 import bigml.api
 import bigmler.utils as u
-import bigmler.resources as r
+import bigmler.resourcesapi.common as r
+import bigmler.resourcesapi.logistic_regressions as rlr
+import bigmler.resourcesapi.batch_predictions as rbp
 import bigmler.pre_model_steps as pms
 import bigmler.processing.args as a
 import bigmler.processing.logisticregressions as plr
 import bigmler.processing.sources as ps
 import bigmler.processing.datasets as pd
 
+from bigmler.resourcesapi.datasets import set_basic_dataset_args
 from bigmler.defaults import DEFAULTS_FILE
 from bigmler.sl_prediction import prediction, remote_prediction
 from bigmler.reports import clear_reports, upload_reports
@@ -41,11 +43,11 @@ from bigmler.dispatcher import (SESSIONS_LOG,
                                 clear_log_files, get_test_dataset,
                                 get_objective_id)
 
-COMMAND_LOG = u".bigmler_logistic_regression"
-DIRS_LOG = u".bigmler_logistic_regression_dir_stack"
+COMMAND_LOG = ".bigmler_logistic_regression"
+DIRS_LOG = ".bigmler_logistic_regression_dir_stack"
 LOG_FILES = [COMMAND_LOG, DIRS_LOG, u.NEW_DIRS_LOG]
 MINIMUM_MODEL = "full=false"
-DEFAULT_OUTPUT = u"predictions.csv"
+DEFAULT_OUTPUT = "predictions.csv"
 
 SETTINGS = {
     "command_log": COMMAND_LOG,
@@ -69,8 +71,7 @@ def logistic_regression_dispatcher(args=sys.argv[1:]):
     if '--evaluate' in args:
         settings.update({"default_output": "evaluation"})
 
-    command_args, command, api, session_file, resume = get_context(args,
-                                                                   settings)
+    command_args, _, api, session_file, _ = get_context(args, settings)
 
     # Selects the action to perform
     if (a.has_train(command_args) or a.has_test(command_args)
@@ -111,7 +112,7 @@ def compute_output(api, args):
                  " to generate the new dataset from it.")
 
     path = u.check_dir(output)
-    session_file = u"%s%s%s" % (path, os.sep, SESSIONS_LOG)
+    session_file = "%s%s%s" % (path, os.sep, SESSIONS_LOG)
     csv_properties = {}
     if args.objective_field:
         csv_properties.update({'objective_field': args.objective_field})
@@ -156,7 +157,7 @@ def compute_output(api, args):
 
     # We update the logistic regression's public state if needed
     if logistic_regression:
-        if isinstance(logistic_regression, basestring):
+        if isinstance(logistic_regression, str):
             if not a.has_test(args):
                 query_string = MINIMUM_MODEL
             elif args.export_fields:
@@ -176,9 +177,9 @@ def compute_output(api, args):
                 logistic_regression_args.update(shared=args.shared)
             if args.public_logistic_regression:
                 logistic_regression_args.update( \
-                    r.set_publish_logistic_regression_args(args))
+                    rlr.set_publish_logistic_regression_args(args))
             if logistic_regression_args:
-                logistic_regression = r.update_logistic_regression( \
+                logistic_regression = rlr.update_logistic_regression( \
                     logistic_regression, logistic_regression_args, args,
                     api=api, path=path, \
                     session_file=session_file)
@@ -215,7 +216,7 @@ def compute_output(api, args):
                 test_source = api.check_resource(test_source_id)
             if test_dataset is None:
                 # create test dataset from test source
-                dataset_args = r.set_basic_dataset_args(args, name=test_name)
+                dataset_args = set_basic_dataset_args(args, name=test_name)
                 test_dataset, resume = pd.alternative_dataset_processing(
                     test_source, "test", dataset_args, api, args,
                     resume, session_file=session_file, path=path, log=log)
@@ -227,7 +228,7 @@ def compute_output(api, args):
                                   objective_field_present=False)
             test_fields = pd.get_fields_structure(test_dataset,
                                                   csv_properties)
-            batch_prediction_args = r.set_batch_prediction_args(
+            batch_prediction_args = rbp.set_batch_prediction_args(
                 args, fields=fields,
                 dataset_fields=test_fields)
 
