@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2014-2016 BigML
+# Copyright 2014-2020 BigML
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -82,7 +82,7 @@ def get_main_options(defaults=None, constants=None):
             'help': ("Number of models to create when using"
                      " ensembles.")},
 
-        # Replacement to use when using bagging.
+        # Replacement to use when sampling.
         '--replacement': {
             'action': 'store_true',
             'default': defaults.get('replacement', False),
@@ -234,16 +234,6 @@ def get_main_options(defaults=None, constants=None):
             'default': defaults.get('ensemble', None),
             'help': "BigML ensemble Id."},
 
-        # If a BigML ensemble is created, creation will use this task-level
-        # parallelism
-        '--tlp': {
-            'action': 'store',
-            'dest': 'tlp',
-            'default': defaults.get('tlp', 1),
-            'type': int,
-            'help': ("BigML ensemble's creation task-level"
-                     " parallelism.")},
-
         # Prediction log format: `short` will only log predictions, `long` will
         # log also confidence information
         '--prediction-info': {
@@ -280,6 +270,20 @@ def get_main_options(defaults=None, constants=None):
             'default': defaults.get('prediction_fields', None),
             'help': "Fields added to the prediction file."},
 
+        # Probability: Includes the probability associated to the prediction
+        '--probability': {
+            'action': 'store_true',
+            'dest': 'probability',
+            'default': defaults.get('probability', False),
+            'help': ("Adding the probability to predictions.")},
+
+        # No_probability: Does not include the probability of the prediction
+        '--no-probability': {
+            'action': 'store_false',
+            'dest': 'probability',
+            'default': defaults.get('probability', False),
+            'help': ("Predictions don't include probability.")},
+
         # Max number of ensembles to create in parallel.
         '--max-parallel-ensembles': {
             'action': 'store',
@@ -411,6 +415,14 @@ def get_main_options(defaults=None, constants=None):
             'help': ("Path to a json file describing batch prediction"
                      " attributes.")},
 
+        # The path to a file containing prediction attributes.
+        '--prediction-attributes': {
+            'action': 'store',
+            'dest': 'prediction_attributes',
+            'default': defaults.get('prediction_attributes', None),
+            'help': ("Path to a json file describing prediction"
+                     " attributes.")},
+
         # Weight-field. Use the contents of the given field as weights.
         '--weight-field': {
             'action': 'store',
@@ -437,6 +449,16 @@ def get_main_options(defaults=None, constants=None):
                      " to next nodes is missing in the input data."
                      " Allowed values: last or proportional")},
 
+        # Default value to use for missings in numeric fields
+        '--default-numeric-value': {
+            'action': 'store',
+            'dest': 'default_numeric_value',
+            'default': defaults.get('default_numeric_value'),
+            'choices': ["mean", "median", "minimum", "maximum", "zero"],
+            'help': ("Value set by default when a numeric field is missing."
+                     " Allowed values: mean, median, minimum, maximum or"
+                     " zero.")},
+
         # Report. Additional output report formats
         '--reports': {
             'action': 'store',
@@ -455,6 +477,26 @@ def get_main_options(defaults=None, constants=None):
             'help': ("Accept missing values as valid in some branches of the"
                      "tree.")},
 
+        # Set it to use the fields and the first node will split in one
+        # branch per category (only for categorical fields)
+        '--split-field': {
+            'action': 'store',
+            'dest': 'split_field',
+            'default': defaults.get('split_field', False),
+            'help': ("Name of the field that should be used in the first"
+                     " split of the model. One branch per category will"
+                     " be created.")},
+
+        # Set it to use the fields and the first node will split in one
+        # branch per category using binary splits (only for categorical fields)
+        '--focus-field': {
+            'action': 'store',
+            'dest': 'focus_field',
+            'default': defaults.get('focus_field', False),
+            'help': ("Name of the field that should be used in the first"
+                     " split of the model. One branch per category will"
+                     " be created.")},
+
         # Random candidates: Number of fields to be selected at random in
         # ensembles construction
         '--random-candidates': {
@@ -465,6 +507,84 @@ def get_main_options(defaults=None, constants=None):
             'help': ("Number of fields selected at random in ensembles'"
                      " construction.")},
 
+        # Ensemble seed. The value used in ensembles as seed
+        '--ensemble-sample-seed': {
+            'action': 'store',
+            'dest': 'ensemble_sample_seed',
+            'default': defaults.get('ensemble_sample_seed', None),
+            'help': "Value used as seed in ensembles."},
+
+        # Ensemble sampling to use when using bagging.
+        '--ensemble-sample-rate': {
+            'action': 'store',
+            'dest': 'ensemble_sample_rate',
+            'default': defaults.get('ensemble_sample_rate', 1.0),
+            'type': float,
+            'help': "Ensemble sampling rate for bagging."},
+
+        # Ensemble replacement to use when using bagging.
+        '--ensemble-sample-no-replacement': {
+            'action': 'store_false',
+            'dest': 'ensemble_sample_replacement',
+            'default': defaults.get('ensemble_sample_replacement', True),
+            'help': "Don't use replacement when bagging."},
+
+        # Create a boosting ensemble
+        '--boosting': {
+            'action': 'store_true',
+            'dest': 'boosting',
+            'default': defaults.get('boosting', False),
+            'help': "Create a boosted ensemble"},
+
+        # Maximum number of iterations used in boosted ensembles.
+        '--boosting-iterations': {
+            'action': 'store',
+            'dest': 'iterations',
+            'default': defaults.get('iterations', None),
+            'type': int,
+            'help': ("Maximum number of iterations used in boosted"
+                     " ensembles.")},
+
+        # The portion of the dataset that will be held out for testing
+        # at the end of every iteration.
+        '--early-holdout': {
+            'action': 'store',
+            'dest': 'early_holdout',
+            'default': defaults.get('early_holdout', None),
+            'type': float,
+            'help': ("The portion of the dataset that will be held out for"
+                     " testing at the end of every iteration in boosted"
+                     " ensembles (between 0 and 1).")},
+
+        # Boosted ensemble: Causes the out of bag samples to be tested after
+        # every iteration.
+        '--no-early-out-of-bag': {
+            'action': 'store_false',
+            'dest': 'early_out_of_bag',
+            'default': defaults.get('early_out_of_bag', True),
+            'help': ("Causes the out of bag samples not to be tested after"
+                     " every iteration in boosted ensembles.")},
+
+        # It controls how aggressively the boosting algorithm will fit the data
+        '--learning-rate': {
+            'action': 'store',
+            'dest': 'learning_rate',
+            'default': defaults.get('learning_rate', None),
+            'type': float,
+            'help': ("It controls how aggressively the boosting algorithm"
+                     " will fit the data in boosted"
+                     " ensembles (between 0 and 1).")},
+
+        # Boosted ensemble: the out_of_bag samples are tested after every
+        # iteration to choose the gradient step size.
+        '--no-step-out-of-bag': {
+            'action': 'store_false',
+            'dest': 'step_out_of_bag',
+            'default': defaults.get('step_out_of_bag', True),
+            'help': ("Causes the out of bag samples not to be tested after"
+                     " every iteration to choose the gradient step size"
+                     " in boosted ensembles.")},
+
         # Disables reports upload.
         '--no-upload': {
             'action': 'store_false',
@@ -479,7 +599,7 @@ def get_main_options(defaults=None, constants=None):
             'default': defaults.get('remote', False),
             'help': "Compute predictions locally"},
 
-        # Deactivate replacement to use when using bagging.
+        # Deactivate replacement to use when using sampling.
         '--no-replacement': {
             'action': 'store_false',
             'dest': 'replacement',
@@ -635,6 +755,14 @@ def get_main_options(defaults=None, constants=None):
             'help': ("Create a dataset as ouput of a batch"
                      " prediction.")},
 
+        # The path to a file containing the operating point description.
+        '--operating-point': {
+            'action': 'store',
+            'dest': 'operating_point',
+            'default': defaults.get('operating_point', None),
+            'help': ("Path to a json file containing the operating "
+                     "point description.")},
+
         # Use median as predicted value in local models predictions
         '--median': {
             'action': 'store_true',
