@@ -16,9 +16,8 @@
 """Parser for BigMLer
 
 """
-from __future__ import absolute_import
 
-import sys
+
 import argparse
 import pkg_resources
 
@@ -66,7 +65,7 @@ def parser_add_options(parser, options):
     """Adds the options to the sucommand parser
 
     """
-    for option, properties in sorted(options.items(), key=lambda x: x[0]):
+    for option, properties in sorted(list(options.items()), key=lambda x: x[0]):
         parser.add_argument(option, **properties)
 
 
@@ -602,20 +601,20 @@ under the License.""" % version
     subcommand_options["fusion"].update(test_options)
     subcommand_options["fusion"].update(source_options)
     subcommand_options["fusion"].update(dataset_options)
-    del(subcommand_options["fusion"]["--train"])
-    del(subcommand_options["fusion"]["--source"])
-    del(subcommand_options["fusion"]["--source-file"])
-    del(subcommand_options["fusion"]["--dataset"])
-    del(subcommand_options["fusion"]["--datasets"])
-    del(subcommand_options["fusion"]["--dataset-file"])
+    del subcommand_options["fusion"]["--train"]
+    del subcommand_options["fusion"]["--source"]
+    del subcommand_options["fusion"]["--source-file"]
+    del subcommand_options["fusion"]["--dataset"]
+    del subcommand_options["fusion"]["--datasets"]
+    del subcommand_options["fusion"]["--dataset-file"]
     subcommand_options["fusion"].update({
         '--prediction-info': main_options['--prediction-info'],
         '--prediction-header': main_options['--prediction-header'],
         '--prediction-fields': main_options['--prediction-fields'],
         '--operating-point': main_options['--operating-point'],
         '--reports': main_options['--reports'],
-         '--project-id': source_options['--project-id'],
-         '--project': source_options['--project'],
+        '--project-id': source_options['--project-id'],
+        '--project': source_options['--project'],
         '--remote': main_options['--remote'],
         '--batch-prediction-attributes': main_options[
             '--batch-prediction-attributes'],
