@@ -18,14 +18,14 @@
    detectors
 
 """
-from __future__ import absolute_import
 
-import bigmler.utils as u
-import bigmler.resources as r
-import bigmler.checkpoint as c
 
 from bigml.fields import Fields, DEFAULT_MISSING_TOKENS
 
+import bigmler.utils as u
+import bigmler.resourcesapi.anomalies as r
+import bigmler.checkpoint as c
+
 def has_anomalies(args):
     """Returns whether some kind of anomaly detector is given
 
