@@ -17,7 +17,7 @@
 """Utilities to parse and transform input args structures
 
 """
-from __future__ import absolute_import
+
 
 import sys
 import os
@@ -31,15 +31,12 @@ from bigml.tree import LAST_PREDICTION, PROPORTIONAL
 
 import bigmler.utils as u
 
-from bigmler.resources import ADD_REMOVE_PREFIX
+from bigmler.resourcesapi.common import ADD_REMOVE_PREFIX
 from bigmler.prediction import FULL_FORMAT, COMBINATION, COMBINATION_LABEL
 from bigmler.train_reader import AGGREGATES
-from bigmler.utils import PYTHON3, check_dir
+from bigmler.utils import check_dir
 
-if PYTHON3:
-    from io import StringIO
-else:
-    from StringIO import StringIO
+from io import StringIO
 
 # Date and time in format SunNov0412_120510 to name and tag resources
 NOW = datetime.datetime.now().strftime("%a%b%d%y_%H%M%S")
@@ -66,9 +63,9 @@ def has_value(args, attrs):
     if isinstance(attrs, list):
         return [hasattr(args, attr) and getattr(args, attr)
                 for attr in attrs]
-    elif isinstance(attrs, basestring):
+    elif isinstance(attrs, str):
         return hasattr(args, attrs) and getattr(args, attrs)
-    return false
+    return False
 
 
 def has_test(args):
@@ -92,7 +89,15 @@ def has_train(args):
     """
     return any(has_value(args, ["training_set", "source", "dataset",
                                 "datasets", "source_file", "dataset_file",
-                                "train_stdin"]))
+                                "train_stdin", "source_tag", "dataset_tag"]))
+
+
+def has_source(args):
+    """Returns if some kind of source is given in args.
+
+    """
+    return any(has_value(args, ["source", "sources", "source_file",
+                                "source_tag"]))
 
 
 def has_model(args):
@@ -132,14 +137,14 @@ def get_flags(args):
     train_stdin = False
     test_stdin = False
     flags = []
-    for i in range(0, len(args)):
-        if args[i].startswith("--"):
+    for i, arg in enumerate(args):
+        if arg.startswith("--"):
             flag = args[i]
             # syntax --flag=value
             value = None
             if "=" in flag:
-                value = args[i][flag.index("="):]
-                args[i] = args[i][0: flag.index("=")]
+                value = arg[flag.index("="):]
+                args[i] = arg[0: flag.index("=")]
             args[i] = args[i].replace("_", "-")
             flag = args[i]
             if value:
@@ -169,7 +174,7 @@ def get_command_message(args):
                 prefix = args[i][0]
                 literal = args[i][1:]
             literal_args[i] = '"%s%s"' % (prefix, literal)
-    return u"bigmler %s\n" % u" ".join(literal_args)
+    return "bigmler %s\n" % " ".join(literal_args)
 
 
 def parse_and_check(command):
@@ -737,7 +742,7 @@ def get_output_args(api, command_args, resume):
     # Retrieve deepnet/ids if provided.
     try:
         if command_args.deepnet_tag:
-            deepnet_regression_ids = (deepnet_ids + \
+            deepnet_ids = (deepnet_ids + \
                 u.list_ids(api.list_deepnets,
                            "tags__in=%s" % command_args.deepnet_tag))
         command_args.deepnet_ids_ = deepnet_ids
@@ -1128,11 +1133,11 @@ def transform_args(command_args, flags, api):
     # Checks combined votes method
     try:
         if (command_args.method and command_args.method != COMBINATION_LABEL
-                and not command_args.method in COMBINATION_WEIGHTS.keys()):
+                and not command_args.method in list(COMBINATION_WEIGHTS.keys())):
             command_args.method = 0
         else:
             combiner_methods = dict(
-                [[value, key] for key, value in COMBINER_MAP.items()])
+                [[value, key] for key, value in list(COMBINER_MAP.items())])
             combiner_methods[COMBINATION_LABEL] = COMBINATION
             command_args.method = combiner_methods.get(command_args.method, 0)
     except AttributeError:
@@ -1142,7 +1147,7 @@ def transform_args(command_args, flags, api):
     try:
         if (command_args.missing_strategy and
                 not (command_args.missing_strategy in
-                     MISSING_STRATEGIES.keys())):
+                     list(MISSING_STRATEGIES.keys()))):
             command_args.missing_strategy = 0
         else:
             command_args.missing_strategy = MISSING_STRATEGIES.get(
@@ -1236,13 +1241,13 @@ def transform_args(command_args, flags, api):
 
     command_args.new_dataset = (
         (hasattr(command_args, 'datasets_json') and
-        command_args.datasets_json) or
+         command_args.datasets_json) or
         (hasattr(command_args, 'multi_dataset') and
-        command_args.multi_dataset) or
+         command_args.multi_dataset) or
         (hasattr(command_args, 'juxtapose') and command_args.juxtapose) or
         (hasattr(command_args, 'sql_query') and command_args.sql_query) or
         (hasattr(command_args, 'sql_output_fields') and
-        command_args.sql_output_fields) or
+         command_args.sql_output_fields) or
         (hasattr(command_args, 'json_query') and
          command_args.json_query))
 
@@ -1259,7 +1264,7 @@ def transform_dataset_options(command_args, api):
         # Parses dataset/id if provided.
         if command_args.datasets:
             dataset_ids = u.read_datasets(command_args.datasets)
-            if len(dataset_ids) > 0:
+            if dataset_ids:
                 command_args.dataset = dataset_ids[-1]
             command_args.dataset_ids = dataset_ids
     except Exception:
@@ -1273,7 +1278,7 @@ def transform_dataset_options(command_args, api):
             dataset_ids = dataset_ids.extend(
                 u.list_ids(api.list_datasets,
                            "tags__in=%s" % command_args.dataset_tag))
-            if len(dataset_ids) > 0:
+            if dataset_ids:
                 command_args.dataset = dataset_ids[-1]
             command_args.dataset_ids = dataset_ids
     except Exception:
@@ -1284,7 +1289,7 @@ def transform_dataset_options(command_args, api):
         if hasattr(command_args, 'datasets_json') \
                 and command_args.datasets_json:
             command_args.dataset_ids = json.loads(command_args.datasets_json)
-            if len(dataset_ids) > 0:
+            if dataset_ids:
                 command_args.dataset = command_args.dataset_ids[-1]
     except AttributeError:
         pass
