@@ -18,14 +18,15 @@
 associations
 
 """
-from __future__ import absolute_import
 
-import bigmler.utils as u
-import bigmler.resources as r
-import bigmler.checkpoint as c
+
 
 from bigml.fields import Fields, DEFAULT_MISSING_TOKENS
 
+import bigmler.utils as u
+import bigmler.resourcesapi.associations as r
+import bigmler.checkpoint as c
+
 
 def has_associations(args):
     """Returns whether there's 'some kind of cluster info
