@@ -17,14 +17,14 @@
 """BigMLer - Resources processing: creation, update and retrieval of clusters
 
 """
-from __future__ import absolute_import
 
-import bigmler.utils as u
-import bigmler.resources as r
-import bigmler.checkpoint as c
 
 from bigml.fields import Fields, DEFAULT_MISSING_TOKENS
 
+import bigmler.utils as u
+import bigmler.resourcesapi.clusters as r
+import bigmler.checkpoint as c
+
 
 def has_clusters(args):
     """Returns whether some kind of cluster
