@@ -17,7 +17,7 @@
 """BigMLer - Resources processing: creation, update and retrieval of datasets
 
 """
-from __future__ import absolute_import
+
 
 import sys
 import re
@@ -29,9 +29,10 @@ from bigml.fields import Fields
 from bigml.predicate import TM_FULL_TERM
 
 import bigmler.utils as u
-import bigmler.resources as r
+import bigmler.resourcesapi.datasets as r
 import bigmler.checkpoint as c
 
+from bigmler.resourcesapi.common import shared_changed
 from bigmler.prediction import OTHER
 
 
@@ -108,7 +109,7 @@ def get_new_objective(fields, objective):
         return None
     try:
         objective_id = fields.field_id(objective)
-    except ValueError, exc:
+    except ValueError as exc:
         sys.exit(exc)
     if fields.objective_field == fields.field_column_number(objective_id):
         return None
@@ -133,7 +134,7 @@ def check_dataset_update(args, dataset):
     """
     return (args.dataset_attributes or
             args.import_fields or
-            (args.shared_flag and r.shared_changed(args.shared, dataset)) or
+            (args.shared_flag and shared_changed(args.shared, dataset)) or
             (((hasattr(args, 'max_categories') and args.max_categories > 0) or
               (hasattr(args, 'multi_label') and args.multi_label)) and
              args.objective_field))
@@ -211,7 +212,7 @@ def dataset_processing(source, api, args, resume,
         #  the --impor-fields flag is used
         if check_dataset_update(args, dataset):
             dataset_args = r.set_dataset_args(args, fields)
-            if args.shared_flag and r.shared_changed(args.shared, dataset):
+            if args.shared_flag and shared_changed(args.shared, dataset):
                 dataset_args.update(shared=args.shared)
             dataset = r.update_dataset(dataset, dataset_args, args,
                                        api=api, path=path,
@@ -363,7 +364,7 @@ def create_categories_datasets(dataset, distribution,
                     "user_metadata":
                     {"max_categories": args.max_categories,
                      "other_label": other_label}}
-            except ValueError, exc:
+            except ValueError as exc:
                 sys.exit(exc)
             new_dataset = r.create_dataset(
                 dataset, dataset_args, args, api=api, path=path,
@@ -381,7 +382,7 @@ def create_new_dataset(datasets, api, args, resume, fields=None,
 
     """
     origin_resource = datasets
-    if not isinstance(datasets, basestring) and args.multi_dataset:
+    if not isinstance(datasets, str) and args.multi_dataset:
         suffix = "multi"
     else:
         datasets = []
