@@ -18,14 +18,15 @@
 of logistic regressiom
 
 """
-from __future__ import absolute_import
 
-import bigmler.utils as u
-import bigmler.resources as r
-import bigmler.checkpoint as c
+
 
 from bigml.fields import Fields, DEFAULT_MISSING_TOKENS
 
+import bigmler.utils as u
+import bigmler.resourcesapi.logistic_regressions as r
+import bigmler.checkpoint as c
+
 
 def has_logistic_regression(args):
     """Returns whether some kind of logistic regression
