@@ -17,10 +17,10 @@
 """BigMLer - Resource processing: creation, update and retrieval of projects
 
 """
-from __future__ import absolute_import
+
 
 import bigml.api
-import bigmler.resources as r
+import bigmler.resourcesapi.projects as r
 import bigmler.utils as u
 import bigmler.checkpoint as c
 
