@@ -17,14 +17,14 @@
 """BigMLer - Resources processing: creation, update and retrieval of samples
 
 """
-from __future__ import absolute_import
 
-import bigmler.utils as u
-import bigmler.resources as r
-import bigmler.checkpoint as c
 
 from bigml.fields import Fields, DEFAULT_MISSING_TOKENS
 
+import bigmler.utils as u
+import bigmler.resourcesapi.samples as r
+import bigmler.checkpoint as c
+
 
 def has_samples(args):
     """Returns whether there's some kind of sample option in the command
