@@ -17,7 +17,7 @@
 """BigMLer - Resources processing: creation, update and retrieval of sources
 
 """
-from __future__ import absolute_import
+
 
 import os
 import csv
@@ -29,7 +29,7 @@ from bigml.fields import Fields
 from bigml.util import bigml_locale
 
 import bigmler.utils as u
-import bigmler.resources as r
+import bigmler.resourcesapi.sources as r
 import bigmler.checkpoint as c
 import bigmler.processing.projects as pp
 
