@@ -17,22 +17,19 @@
 """BigMLer - project creation and update
 
 """
-from __future__ import absolute_import
+
 
 import sys
-import os
-import shutil
 
 import bigmler.utils as u
-import bigmler.processing.args as a
 import bigmler.processing.projects as pp
 
 from bigmler.defaults import DEFAULTS_FILE
 from bigmler.command import get_context
 from bigmler.dispatcher import SESSIONS_LOG, clear_log_files
 
-COMMAND_LOG = u".bigmler_project"
-DIRS_LOG = u".bigmler_project_dir_stack"
+COMMAND_LOG = ".bigmler_project"
+DIRS_LOG = ".bigmler_project_dir_stack"
 LOG_FILES = [COMMAND_LOG, DIRS_LOG, u.NEW_DIRS_LOG]
 
 SETTINGS = {
@@ -47,8 +44,7 @@ def project_dispatcher(args=sys.argv[1:]):
 
     """
 
-    command_args, command, api, session_file, resume = get_context(args,
-                                                                   SETTINGS)
+    command_args, _, api, session_file, _ = get_context(args, SETTINGS)
 
     path = u.check_dir(command_args.output)
     log = None
