@@ -16,7 +16,7 @@
 """Linear regression prediction auxiliary functions
 
 """
-from __future__ import absolute_import
+
 
 
 import sys
@@ -30,8 +30,7 @@ import bigmler.utils as u
 import bigmler.checkpoint as c
 
 from bigmler.tst_reader import TstReader as TestReader
-from bigmler.resources import NORMAL_FORMAT, FULL_FORMAT
-from bigmler.resources import create_batch_projection
+from bigmler.resourcesapi.batch_projections import create_batch_projection
 
 
 def use_projection_headers(projection_headers, output, test_reader,
@@ -50,8 +49,6 @@ def use_projection_headers(projection_headers, output, test_reader,
 
     input_headers = []
 
-
-
     if args.projection_fields:
 
         if test_reader.has_headers():
