@@ -17,22 +17,19 @@
 """BigMLer - reify processing dispatching
 
 """
-from __future__ import absolute_import
+
 
 import sys
-import os
-import shutil
 
 import bigmler.utils as u
-import bigmler.processing.args as a
 
 from bigmler.defaults import DEFAULTS_FILE
 from bigmler.command import get_context
 from bigmler.dispatcher import SESSIONS_LOG, clear_log_files
 from bigmler.reify.reify import reify_resources
 
-COMMAND_LOG = u".bigmler_reify"
-DIRS_LOG = u".bigmler_reify_dir_stack"
+COMMAND_LOG = ".bigmler_reify"
+DIRS_LOG = ".bigmler_reify_dir_stack"
 LOG_FILES = [COMMAND_LOG, DIRS_LOG, u.NEW_DIRS_LOG]
 DEFAULT_OUTPUT = "reify.py"
 
@@ -53,8 +50,7 @@ def reify_dispatcher(args=sys.argv[1:]):
     if "--clear-logs" in args:
         clear_log_files(LOG_FILES)
 
-    command_args, command, api, session_file, resume = get_context(args,
-                                                                   SETTINGS)
+    command_args, _, api, session_file, _ = get_context(args, SETTINGS)
 
     def logger(message):
         """Partial to log messages according to args.verbosity
@@ -66,7 +62,7 @@ def reify_dispatcher(args=sys.argv[1:]):
     message = "Starting reification for %s\n\n" % command_args.resource_id
     u.log_message(message, \
         log_file=session_file, console=command_args.verbosity)
-    reify_resources(command_args, api, logger)
+    reify_resources(command_args, api)
     message = "\nReification complete. See the results in %s\n\n" % \
         command_args.output
     u.log_message(message, \
