@@ -17,29 +17,29 @@
 """BigMLer - sample subcommand processing dispatching
 
 """
-from __future__ import absolute_import
+
 
 import sys
 import os
-import shutil
 
 import bigmler.utils as u
-import bigmler.resources as r
+import bigmler.resourcesapi.samples as r
 import bigmler.pre_model_steps as pms
 import bigmler.processing.args as a
 import bigmler.processing.samples as psa
 
+from bigmler.resourcesapi.common import shared_changed
 from bigmler.defaults import DEFAULTS_FILE
 from bigmler.command import get_context
 from bigmler.dispatcher import SESSIONS_LOG, clear_log_files
 from bigmler.sampleoutput import sample_file
 from bigmler.reports import clear_reports, upload_reports
 
-COMMAND_LOG = u".bigmler_sample"
-DIRS_LOG = u".bigmler_sample_dir_stack"
+COMMAND_LOG = ".bigmler_sample"
+DIRS_LOG = ".bigmler_sample_dir_stack"
 LOG_FILES = [COMMAND_LOG, DIRS_LOG, u.NEW_DIRS_LOG]
 MINIMUM_MODEL = "full=false"
-DEFAULT_OUTPUT = u"sample.csv"
+DEFAULT_OUTPUT = "sample.csv"
 
 SETTINGS = {
     "command_log": COMMAND_LOG,
@@ -65,8 +65,7 @@ def sample_dispatcher(args=sys.argv[1:]):
     if "--clear-logs" in args:
         clear_log_files(LOG_FILES)
 
-    command_args, command, api, session_file, resume = get_context(args,
-                                                                   SETTINGS)
+    command_args, _, api, session_file, resume = get_context(args, SETTINGS)
 
     # Selects the action to perform
     if a.has_train(command_args) or has_sample(command_args):
@@ -103,7 +102,7 @@ def compute_output(api, args):
                  " to generate the new dataset from it.")
 
     path = u.check_dir(output)
-    session_file = u"%s%s%s" % (path, os.sep, SESSIONS_LOG)
+    session_file = "%s%s%s" % (path, os.sep, SESSIONS_LOG)
     csv_properties = {}
     # If logging is required set the file for logging
     log = None
@@ -139,14 +138,14 @@ def compute_output(api, args):
 
     # We update the sample's public state if needed
     if sample:
-        if isinstance(sample, basestring):
+        if isinstance(sample, str):
             # build the query string from the sample options
             sample = u.check_resource(sample, api.get_sample)
         samples[0] = sample
         if (args.public_sample or
-                (args.shared_flag and r.shared_changed(args.shared, sample))):
+                (args.shared_flag and shared_changed(args.shared, sample))):
             sample_args = {}
-            if args.shared_flag and r.shared_changed(args.shared, sample):
+            if args.shared_flag and shared_changed(args.shared, sample):
                 sample_args.update(shared=args.shared)
             if args.public_sample:
                 sample_args.update(r.set_publish_sample_args(args))
