@@ -16,14 +16,14 @@
 """Sample output auxiliary functions
 
 """
-from __future__ import absolute_import
+
 
 
 import json
 import os
 
 from bigml.io import UnicodeWriter
-import bigmler.resources as r
+import bigmler.resourcesapi.samples as r
 
 
 STAT_KEYS = ["spearman_correlation", "pearson_correlation", "slope",
@@ -38,13 +38,13 @@ def translate_to_id(value, fields):
     """
     try:
         prefix = ""
-        if isinstance(value, basestring):
+        if isinstance(value, str):
             if value.startswith("-"):
                 value = value[1:]
                 prefix = "-"
             return "%s%s" % (prefix, fields.field_id(value))
     except ValueError:
-        print "WARNING: Failed to find \"%s\" in the sample fields structure"
+        print("WARNING: Failed to find \"%s\" in the sample fields structure")
         return None
     if isinstance(value, list):
         ids = []
@@ -59,6 +59,7 @@ def translate_to_id(value, fields):
                 print ("WARNING: Failed to find \"%s\" in the sample fields"
                        " structure")
         return ids
+    return None
 
 
 def sample_query_string(args, fields):
