@@ -13,7 +13,7 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-from __future__ import absolute_import
+
 
 import os
 import time
@@ -24,8 +24,7 @@ from bigml.api import check_resource
 from bigml.io import UnicodeReader
 from bigmler.processing.models import MONTECARLO_FACTOR
 from bigmler.checkpoint import file_number_of_lines
-from bigmler.utils import storage_file_name, open_mode, decode2
-from bigmler.utils import PYTHON3
+from bigmler.utils import storage_file_name, open_mode
 from bigmler.tests.common_steps import check_debug
 from nose.tools import ok_, assert_equal, assert_not_equal
 
@@ -152,7 +151,7 @@ def i_check_create_lr_model(step):
         world.logistic_regression = lr
         lr_file.close()
         assert True
-    except Exception, exc:
+    except Exception as exc:
         assert False, str(exc)
 
 
