@@ -13,7 +13,7 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-from __future__ import absolute_import
+
 
 
 import os
@@ -29,9 +29,8 @@ from bigml.api import check_resource
 from bigmler.checkpoint import file_number_of_lines
 from bigmler.tests.common_steps import check_debug
 from bigmler.tests.basic_tst_prediction_steps import shell_execute
-from bigmler.utils import PYTHON3
 
-CAT = u"type " if sys.platform == "win32" else u"cat "
+CAT = "type " if sys.platform == "win32" else "cat "
 
 #@step(r'I create BigML resources uploading train "(.*)" file to test "(.*)" read from stdin with name "(.*)" and log predictions in "(.*)"$')
 def i_create_all_resources_to_test_from_stdin(step, data=None, test=None, name=None, output=None):
@@ -39,12 +38,10 @@ def i_create_all_resources_to_test_from_stdin(step, data=None, test=None, name=N
         assert False
 
     test = res_filename(test)
-    if not PYTHON3:
-        name = name.decode("utf-8")
 
-    command = (CAT + test + u"|bigmler --train " + res_filename(data) +
-               u" --test --store --output " + output + u" --name \"" +
-               name + u"\" --max-batch-models 1")
+    command = (CAT + test + "|bigmler --train " + res_filename(data) +
+               " --test --store --output " + output + " --name \"" +
+               name + "\" --max-batch-models 1")
     shell_execute(command, output, test=test)
 
 
@@ -52,7 +49,7 @@ def i_create_all_resources_to_test_from_stdin(step, data=None, test=None, name=N
 def i_create_source_from_stdin(step, data=None, output_dir=None):
     if data is None or output_dir is None:
         assert False
-    command = (CAT + res_filename(data) + u"|bigmler --train " +
-               u"--store --no-dataset --no-model --output-dir " +
-               output_dir + u" --max-batch-models 1")
+    command = (CAT + res_filename(data) + "|bigmler --train " +
+               "--store --no-dataset --no-model --output-dir " +
+               output_dir + " --max-batch-models 1")
     shell_execute(command, output_dir + "/test", test=None)
