@@ -19,7 +19,7 @@
 """ Testing shared resources
 
 """
-from __future__ import absolute_import
+
 
 
 from bigmler.tests.world import (world, common_setup_module,
@@ -47,14 +47,14 @@ class TestShared(object):
         """Calling generic teardown for every method
 
         """
-        print "\nEnd of tests in: %s\n-------------------\n" % __name__
+        print("\nEnd of tests in: %s\n-------------------\n" % __name__)
         teardown_class()
 
     def setup(self):
         """
             Debug information
         """
-        print "\n-------------------\nTests in: %s\n" % __name__
+        print("\n-------------------\nTests in: %s\n" % __name__)
 
     def test_scenario1(self):
         """
@@ -69,11 +69,11 @@ class TestShared(object):
                 | data               | output                     |
                 | ../data/iris.csv   | ./scenario_sh_1/evaluation |
         """
-        print self.test_scenario1.__doc__
+        print(self.test_scenario1.__doc__)
         examples = [
             ['data/iris.csv', 'scenario_sh_1/evaluation']]
         for example in examples:
-            print "\nTesting with:\n", example
+            print("\nTesting with:\n", example)
             test_pred.i_create_all_resources_to_evaluate_and_share(self, data=example[0], output=example[1])
             test_pred.i_check_create_source(self)
             test_pred.i_check_create_dataset_shared(self)
