@@ -19,11 +19,11 @@
 """ Testing Multi-label evaluations
 
 """
-from __future__ import absolute_import
+
 
 
 from bigmler.tests.world import (world, common_setup_module,
-                                 common_teardown_module, teardown_class, PY3)
+                                 common_teardown_module, teardown_class)
 
 import bigmler.tests.basic_tst_prediction_steps as test_pred
 import bigmler.tests.ml_tst_prediction_steps as ml_pred
@@ -51,14 +51,14 @@ class TestMLEvaluation(object):
         """Calling generic teardown for every method
 
         """
-        print "\nEnd of tests in: %s\n-------------------\n" % __name__
+        print("\nEnd of tests in: %s\n-------------------\n" % __name__)
         teardown_class()
 
     def setup(self):
         """
             Debug information
         """
-        print "\n-------------------\nTests in: %s\n" % __name__
+        print("\n-------------------\nTests in: %s\n" % __name__)
 
     def setup_scenario1(self):
         """
@@ -75,11 +75,11 @@ class TestMLEvaluation(object):
                 |tag |label_separator |number_of_labels| data                   |training_separator |  output                          |json_evaluation_file
                 |my_multilabel_e_1|:|7| ../data/multilabel.csv |,| ./scenario_ml_e1/evaluation | ./check_files/evaluation_ml.json
         """
-        print self.setup_scenario1.__doc__
+        print(self.setup_scenario1.__doc__)
         examples = [
-            ['my_multilabel_e_1%s' % PY3, ':', '7', 'data/multilabel.csv', ',', 'scenario_ml_e1/evaluation', 'check_files/evaluation_ml.json']]
+            ['my_multilabel_e_1', ':', '7', 'data/multilabel.csv', ',', 'scenario_ml_e1/evaluation', 'check_files/evaluation_ml.json']]
         for example in examples:
-            print "\nTesting with:\n", example
+            print("\nTesting with:\n", example)
             ml_eval.i_create_all_ml_evaluations(self, tag=example[0], label_separator=example[1], number_of_labels=example[2], data=example[3], training_separator=example[4], output=example[5])
             test_pred.i_check_create_source(self)
             test_pred.i_check_create_dataset(self)
@@ -103,11 +103,11 @@ class TestMLEvaluation(object):
                 |scenario    | kwargs                                                  | number_of_labels                    | output                        |json_evaluation_file          |
                 | scenario_ml_e1| {"tag": "my_multilabel_e_1", "data": "../data/multilabel.csv", "label_separator": ":", "number_of_labels": 7, "training_separator": ",", "output": "./scenario_ml_e1/evaluation"}   | 7 | ./scenario_ml_e2/evaluation   | ./check_files/evaluation_ml.json   |
         """
-        print self.test_scenario2.__doc__
+        print(self.test_scenario2.__doc__)
         examples = [
-            ['scenario_ml_e1', '{"tag": "my_multilabel_e_1%s", "data": "data/multilabel.csv", "label_separator": ":", "number_of_labels": 7, "training_separator": ",", "output": "scenario_ml_e1/evaluation"}' % PY3, '7', 'scenario_ml_e2/evaluation', 'check_files/evaluation_ml.json']]
+            ['scenario_ml_e1', '{"tag": "my_multilabel_e_1", "data": "data/multilabel.csv", "label_separator": ":", "number_of_labels": 7, "training_separator": ",", "output": "scenario_ml_e1/evaluation"}', '7', 'scenario_ml_e2/evaluation', 'check_files/evaluation_ml.json']]
         for example in examples:
-            print "\nTesting with:\n", example
+            print("\nTesting with:\n", example)
             test_pred.i_have_previous_scenario_or_reproduce_it(self, example[0], example[1])
             ml_eval.i_create_ml_evaluations_from_source(self, output=example[3])
             test_pred.i_check_create_dataset(self)
@@ -130,11 +130,11 @@ class TestMLEvaluation(object):
                 |scenario    | kwargs                                                  | number_of_labels                    | output                        |json_evaluation_file          |
                 | scenario_ml_e1| {"tag": "my_multilabel_e_1", "data": "../data/multilabel.csv", "label_separator": ":", "number_of_labels": 7, "training_separator": ",", "output": "./scenario_ml_e1/evaluation"}   | 7 | ./scenario_ml_e3/evaluation   | ./check_files/evaluation_ml.json   |
         """
-        print self.test_scenario3.__doc__
+        print(self.test_scenario3.__doc__)
         examples = [
-            ['scenario_ml_e1', '{"tag": "my_multilabel_e_1%s", "data": "data/multilabel.csv", "label_separator": ":", "number_of_labels": 7, "training_separator": ",", "output": "scenario_ml_e1/evaluation"}' % PY3, '7', 'scenario_ml_e3/evaluation', 'check_files/evaluation_ml.json']]
+            ['scenario_ml_e1', '{"tag": "my_multilabel_e_1", "data": "data/multilabel.csv", "label_separator": ":", "number_of_labels": 7, "training_separator": ",", "output": "scenario_ml_e1/evaluation"}', '7', 'scenario_ml_e3/evaluation', 'check_files/evaluation_ml.json']]
         for example in examples:
-            print "\nTesting with:\n", example
+            print("\nTesting with:\n", example)
             test_pred.i_have_previous_scenario_or_reproduce_it(self, example[0], example[1])
             ml_eval.i_create_ml_evaluations_from_dataset(self, output=example[3])
             test_pred.i_check_create_models(self)
@@ -155,11 +155,11 @@ class TestMLEvaluation(object):
             |scenario    | kwargs                                                  | models_file | number_of_labels                    | output                        |key          | value
             | scenario_ml_e1| {"tag": "my_multilabel_e_1", "data": "../data/multilabel.csv", "label_separator": ":", "number_of_labels": 7, "training_separator": ",", "output": "./scenario_ml_e1/evaluation"}   | ./scenario_ml_e1/models | 7 | ./scenario_ml_e4/evaluation   | average_phi   | 0.8180
         """
-        print self.test_scenario4.__doc__
+        print(self.test_scenario4.__doc__)
         examples = [
-            ['scenario_ml_e1', '{"tag": "my_multilabel_e_1%s", "data": "data/multilabel.csv", "label_separator": ":", "number_of_labels": 7, "training_separator": ",", "output": "scenario_ml_e1/evaluation"}' % PY3, 'scenario_ml_e1/models', '7', 'scenario_ml_e4/evaluation', 'average_phi', '0.8180']]
+            ['scenario_ml_e1', '{"tag": "my_multilabel_e_1", "data": "data/multilabel.csv", "label_separator": ":", "number_of_labels": 7, "training_separator": ",", "output": "scenario_ml_e1/evaluation"}', 'scenario_ml_e1/models', '7', 'scenario_ml_e4/evaluation', 'average_phi', '0.8180']]
         for example in examples:
-            print "\nTesting with:\n", example
+            print("\nTesting with:\n", example)
             test_pred.i_have_previous_scenario_or_reproduce_it(self, example[0], example[1])
             ml_eval.i_create_ml_evaluations_from_models(self, models_file=example[2], output=example[4])
             test_pred.i_check_create_evaluations(self, number_of_evaluations=example[3])
@@ -180,11 +180,11 @@ class TestMLEvaluation(object):
                 | scenario_ml_e1| {"tag": "my_multilabel_e_1", "data": "../data/multilabel.csv", "label_separator": ":", "number_of_labels": 7, "training_separator": ",", "output": "./scenario_ml_e1/evaluation"}   | my_multilabel_e_1 | 7 | ./scenario_ml_e5/evaluation   | average_phi   | 0.8180
 
         """
-        print self.test_scenario5.__doc__
+        print(self.test_scenario5.__doc__)
         examples = [
-            ['scenario_ml_e1', '{"tag": "my_multilabel_e_1%s", "data": "data/multilabel.csv", "label_separator": ":", "number_of_labels": 7, "training_separator": ",", "output": "scenario_ml_e1/evaluation"}' % PY3, 'my_multilabel_e_1%s' % PY3 , '7', 'scenario_ml_e5/evaluation', 'average_phi', '0.8180']]
+            ['scenario_ml_e1', '{"tag": "my_multilabel_e_1", "data": "data/multilabel.csv", "label_separator": ":", "number_of_labels": 7, "training_separator": ",", "output": "scenario_ml_e1/evaluation"}', 'my_multilabel_e_1' , '7', 'scenario_ml_e5/evaluation', 'average_phi', '0.8180']]
         for example in examples:
-            print "\nTesting with:\n", example
+            print("\nTesting with:\n", example)
             test_pred.i_have_previous_scenario_or_reproduce_it(self, example[0], example[1])
             ml_eval.i_create_ml_evaluations_from_tagged_models(self, tag=example[2], output=example[4])
             test_pred.i_check_create_evaluations(self, number_of_evaluations=example[3])
