@@ -19,7 +19,7 @@
 """ Testing deepnet predictions creation
 
 """
-from __future__ import absolute_import
+
 
 from bigmler.tests.world import (world, common_setup_module,
                                  common_teardown_module,
@@ -52,14 +52,14 @@ class TestPrediction(object):
         """
             Debug information
         """
-        print "\n-------------------\nTests in: %s\n" % __name__
+        print("\n-------------------\nTests in: %s\n" % __name__)
 
     def teardown(self):
         """Calling generic teardown for every method
 
         """
         self.world = teardown_class()
-        print "\nEnd of tests in: %s\n-------------------\n" % __name__
+        print("\nEnd of tests in: %s\n-------------------\n" % __name__)
 
     def test_scenario01(self):
         """
@@ -77,11 +77,11 @@ class TestPrediction(object):
 
 
         """
-        print self.test_scenario01.__doc__
+        print(self.test_scenario01.__doc__)
         examples = [
             ['data/iris_nh.csv', 'data/test_iris_nh.csv', 'scenario1_dn_nh/predictions.csv', 'check_files/predictions_iris_dn.csv']]
         for example in examples:
-            print "\nTesting with:\n", example
+            print("\nTesting with:\n", example)
             dn_pred.i_create_all_dn_resources_with_no_headers(self, example[0], example[1], example[2])
             test_pred.i_check_create_source(self)
             test_pred.i_check_create_dataset(self, suffix=None)
@@ -103,12 +103,12 @@ class TestPrediction(object):
             | data               | test                    | output                        |predictions_file           |
             | ../data/iris.csv   | ../data/test_iris.csv   | ./scenario1_dn/predictions.csv   | ./check_files/predictions_iris_dn.csv   |
         """
-        print self.setup_scenario02.__doc__
+        print(self.setup_scenario02.__doc__)
         examples = [
             ['data/iris.csv', 'data/test_iris.csv', 'scenario1_dn/predictions.csv', 'check_files/predictions_iris_dn.csv'],
             ['data/grades.csv', 'data/test_grades.csv', 'scenario1_r_dn/predictions.csv', 'check_files/predictions_grades_dn.csv']]
         for example in examples:
-            print "\nTesting with:\n", example
+            print("\nTesting with:\n", example)
             dn_pred.i_create_all_dn_resources(self, example[0], example[1], example[2])
             test_pred.i_check_create_source(self)
             test_pred.i_check_create_dataset(self, suffix=None)
@@ -130,11 +130,11 @@ class TestPrediction(object):
             |scenario    | kwargs                                                  | test                    | output                        |predictions_file           |
             | scenario1| {"data": "../data/iris.csv", "output": "./scenario1_dn/predictions.csv", "test": "../data/test_iris.csv"}   | ../data/test_iris.csv   | ./scenario2/predictions.csv   | ./check_files/predictions_iris.csv   |
         """
-        print self.test_scenario03.__doc__
+        print(self.test_scenario03.__doc__)
         examples = [
             ['scenario1_dn', '{"data": "data/iris.csv", "output": "scenario1_dn/predictions.csv", "test": "data/test_iris.csv"}', 'data/test_iris.csv', 'scenario2_dn/predictions.csv', 'check_files/predictions_iris_dn.csv']]
         for example in examples:
-            print "\nTesting with:\n", example
+            print("\nTesting with:\n", example)
             test_pred.i_have_previous_scenario_or_reproduce_it(self, example[0], example[1])
             dn_pred.i_create_dn_resources_from_source(self, None, test=example[2], output=example[3])
             test_pred.i_check_create_dataset(self, suffix=None)
@@ -157,11 +157,11 @@ class TestPrediction(object):
             | scenario1| {"data": "../data/iris.csv", "output": "./scenario1/predictions.csv", "test": "../data/test_iris.csv"}   | ../data/test_iris.csv   | ./scenario3/predictions.csv   | ./check_files/predictions_iris.csv   |
 
         """
-        print self.test_scenario04.__doc__
+        print(self.test_scenario04.__doc__)
         examples = [
             ['scenario1_dn', '{"data": "data/iris.csv", "output": "scenario1_dn/predictions.csv", "test": "data/test_iris.csv"}', 'data/test_iris.csv', 'scenario3_dn/predictions.csv', 'check_files/predictions_iris_dn.csv']]
         for example in examples:
-            print "\nTesting with:\n", example
+            print("\nTesting with:\n", example)
             test_pred.i_have_previous_scenario_or_reproduce_it(self, example[0], example[1])
             dn_pred.i_create_dn_resources_from_dataset(self, None, test=example[2], output=example[3])
             dn_pred.i_check_create_dn_model(self)
@@ -181,11 +181,11 @@ class TestPrediction(object):
             | scenario1| {"data": "../data/iris.csv", "output": "./scenario1/predictions.csv", "test": "../data/test_iris.csv"}   | ../data/test_iris.csv   | ./scenario4/predictions.csv   | ./check_files/predictions_iris.csv   |
 
         """
-        print self.test_scenario05.__doc__
+        print(self.test_scenario05.__doc__)
         examples = [
             ['scenario1_dn', '{"data": "data/iris.csv", "output": "scenario1_dn/predictions.csv", "test": "data/test_iris.csv"}', 'data/test_iris.csv', 'scenario4_dn/predictions.csv', 'check_files/predictions_iris_dn.csv']]
         for example in examples:
-            print "\nTesting with:\n", example
+            print("\nTesting with:\n", example)
             test_pred.i_have_previous_scenario_or_reproduce_it(self, example[0], example[1])
             dn_pred.i_create_dn_resources_from_model(self, test=example[2], output=example[3])
             test_pred.i_check_create_predictions(self)
@@ -204,11 +204,11 @@ class TestPrediction(object):
             | scenario1| {"data": "../data/iris.csv", "output": "./scenario1/predictions.csv", "test": "../data/test_iris.csv"}   | ../data/test_iris.csv   | ./scenario4/predictions.csv   | ./check_files/predictions_iris.csv   |
 
         """
-        print self.test_scenario06.__doc__
+        print(self.test_scenario06.__doc__)
         examples = [
             ['scenario1_dn', '{"data": "data/iris.csv", "output": "scenario1_dn/predictions.csv", "test": "data/test_iris.csv"}', 'data/test_iris.csv', 'scenario5_dn/predictions.csv', 'check_files/predictions_iris_dn.csv']]
         for example in examples:
-            print "\nTesting with:\n", example
+            print("\nTesting with:\n", example)
             test_pred.i_have_previous_scenario_or_reproduce_it(self, example[0], example[1])
             dn_pred.i_create_dn_resources_from_model_remote(self, test=example[2], output=example[3])
             batch_pred.i_check_create_batch_prediction(self)
@@ -228,11 +228,11 @@ class TestPrediction(object):
             | scenario1| {"data": "../data/iris.csv", "output": "./scenario1/predictions.csv", "test": "../data/test_iris.csv"}   | ../data/test_iris.csv   | ../data/batch_output.json  | ./scenario6_dn/predictions.csv   | ./check_files/predictions_iris.csv   |
 
         """
-        print self.test_scenario07.__doc__
+        print(self.test_scenario07.__doc__)
         examples = [
             ['scenario1_dn', '{"data": "data/iris.csv", "output": "scenario1_dn/predictions.csv", "test": "data/test_iris.csv"}', 'data/test_iris.csv', 'data/batch_output.json', 'scenario6_dn/predictions.csv', 'check_files/predictions_iris_dn_prob.csv']]
         for example in examples:
-            print "\nTesting with:\n", example
+            print("\nTesting with:\n", example)
             test_pred.i_have_previous_scenario_or_reproduce_it(self, example[0], example[1])
             dn_pred.i_create_dn_resources_from_model_remote_with_options(self, test=example[2], output=example[4], options_file=example[3])
             batch_pred.i_check_create_batch_prediction(self)
@@ -253,12 +253,12 @@ class TestPrediction(object):
             | data               | test                    | output                        |predictions_file           |
             | ../data/iris.csv   | ../data/test_iris.csv   | ./scenario1_dn/predictions.csv   | ./check_files/predictions_iris_dn.csv   |
         """
-        print self.test_scenario08.__doc__
+        print(self.test_scenario08.__doc__)
         examples = [
             ['data/iris.csv', 'data/test_iris.csv', 'scenario8_dn/predictions.csv', 'check_files/predictions_iris_dn_h.csv'],
             ['data/grades.csv', 'data/test_grades.csv', 'scenario8_r_dn/predictions.csv', 'check_files/predictions_grades_dn_h.csv']]
         for example in examples:
-            print "\nTesting with:\n", example
+            print("\nTesting with:\n", example)
             dn_pred.i_create_all_dn_resources_headers(self, example[0], example[1], example[2])
             test_pred.i_check_create_source(self)
             test_pred.i_check_create_dataset(self, suffix=None)
