@@ -17,7 +17,7 @@
 """Utilities for BigMLer
 
 """
-from __future__ import absolute_import
+
 
 import fileinput
 import ast
@@ -37,10 +37,9 @@ from bigml.util import console_log, empty_resource
 from bigml.fields import get_fields_structure, Fields
 from bigml.io import UnicodeReader
 
-PYTHON3 = sys.version_info[0] == 3
 PAGE_LENGTH = 200
 ATTRIBUTE_NAMES = ['name', 'label', 'description']
-NEW_DIRS_LOG = u".bigmler_dirs"
+NEW_DIRS_LOG = ".bigmler_dirs"
 BRIEF_MODEL_QS = "exclude=root,fields"
 
 # Base Domain
@@ -249,8 +248,7 @@ def read_votes_files(dirs_list, path):
             predictions_files.append("%s%s%s" % (os.getcwd(),
                                                  os.sep, predictions_file))
             message = "%s\n" % predictions_file
-            if PYTHON3:
-                message = message.encode(FILE_ENCODING)
+            message = message.encode(FILE_ENCODING)
             group_predictions.write(message)
         os.chdir(current_directory)
     group_predictions.close()
@@ -308,7 +306,7 @@ def list_ids(api_function, query_string, status_code=bigml.api.FINISHED,
            (resources['meta']['total_count'] > (resources['meta']['offset'] +
                                                 resources['meta']['limit']))):
         offset = resources['meta']['offset'] + PAGE_LENGTH
-        q_s = 'status.code=%s;offset=%s;limit=%s;%s' % (
+        q_s = 'status.code=%s;offset=%s;%s;%s' % (
             status_code, offset, limit_s, query_string)
         resources = api_function(q_s)
         if resources['objects']:
@@ -347,9 +345,9 @@ def check_dir(path):
     directory = os.path.dirname(path)
     if directory == "":
         directory = "."
-    if len(directory) > 0 and not os.path.exists(directory):
+    if directory and not os.path.exists(directory):
         os.makedirs(directory)
-        sys_log_message(u"%s\n" % os.path.abspath(directory),
+        sys_log_message("%s\n" % os.path.abspath(directory),
                         log_file=NEW_DIRS_LOG)
 
     return directory
@@ -359,29 +357,28 @@ def print_tree(directory, padding):
     """Returns a graphical directory tree structure as a string
 
     """
-    if padding != u' ':
-        output = padding[:-1] + u'├─'
+    if padding != ' ':
+        output = padding[:-1] + '├─'
     else:
         output = padding
-    output += os.path.basename(os.path.abspath(directory)) + u'\n'
-    padding = padding + u' '
+    output += os.path.basename(os.path.abspath(directory)) + '\n'
+    padding = padding + ' '
     files = []
     files = os.listdir(directory)
     count = 0
-    for i in range(0, len(files)):
-        file_name = files[i]
+    for i, file_name in enumerate(files):
         count += 1
         path = directory + os.sep + file_name
         if os.path.isdir(path):
             if count == len(files):
-                output += print_tree(path, padding + u' ')
+                output += print_tree(path, padding + ' ')
             else:
-                output += print_tree(path, padding + u'|')
+                output += print_tree(path, padding + '|')
         else:
             if i < (len(files) - 1):
-                output += padding + u'├─' + file_name + u'\n'
+                output += padding + '├─' + file_name + '\n'
             else:
-                output += padding + u'└─' + file_name + u'\n'
+                output += padding + '└─' + file_name + '\n'
     return output
 
 
@@ -418,15 +415,12 @@ def log_message(message, log_file=None, console=False):
        If console is True, sends the message to console.
     """
 
-    if isinstance(message, unicode) and not PYTHON3:
-        message = message.encode(FILE_ENCODING)
     if console:
         console_log(message)
     if log_file is not None:
-        if PYTHON3:
-            message = message.encode(FILE_ENCODING)
-        with open(log_file, 'ab', 0) as log_file:
-            log_file.write(message)
+        message = message.encode(FILE_ENCODING)
+        with open(log_file, 'ab', 0) as log_handler:
+            log_handler.write(message)
 
 
 def sys_log_message(message, log_file=None, mode='ab'):
@@ -434,11 +428,12 @@ def sys_log_message(message, log_file=None, mode='ab'):
 
        If log_file is set, logs the message in the file.
     """
-    if PYTHON3 or isinstance(message, unicode):
-        message = message.encode(BIGML_SYS_ENCODING)
+    message = message.encode(BIGML_SYS_ENCODING)
+    if not mode.endswith("b"):
+        mode = "%sb" % mode
     if log_file is not None:
-        with open(log_file, mode, 0) as log_file:
-            log_file.write(message)
+        with open(log_file, mode) as log_handler:
+            log_handler.write(message)
 
 
 def plural(text, num):
@@ -467,7 +462,7 @@ def check_resource_error(resource, message):
     return bigml.api.get_resource_id(resource)
 
 
-def log_created_resources(file_name, path, resource_id, mode='w',
+def log_created_resources(file_name, path, resource_id, mode='ab',
                           comment=None):
     """Logs the created resources ids in the given file
 
@@ -477,12 +472,12 @@ def log_created_resources(file_name, path, resource_id, mode='w',
         try:
             message = ""
             if resource_id is not None:
-                message = u"%s\n" % resource_id
+                message = "%s\n" % resource_id
             if comment is not None:
-                message = u"%s%s" % (message, comment)
-            sys_log_message(message, file_name)
-        except IOError, exc:
-            print "Failed to write %s: %s" % (file_name, str(exc))
+                message = "%s%s" % (message, comment)
+            sys_log_message(message, file_name, mode)
+        except IOError as exc:
+            print("Failed to write %s: %s" % (file_name, str(exc)))
 
 
 def check_resource(*args, **kwargs):
@@ -493,7 +488,7 @@ def check_resource(*args, **kwargs):
         kwargs.update({"raise_on_error": True})
         result = bigml.api.check_resource(*args, **kwargs)
         return result
-    except Exception, exc:
+    except Exception as exc:
         sys.exit("\nFailed to obtain a finished resource:\n%s." % str(exc))
 
 
@@ -516,7 +511,7 @@ def objective_field_names(models_or_ensembles, api):
                     try:
                         model = check_resource(model_id, api.get_model,
                                                query_string=BRIEF_MODEL_QS)
-                    except ValueError, exception:
+                    except ValueError as exception:
                         sys.exit("Failed to get a finished model: %s" %
                                  str(exception))
                     name = objective_field_name(model, api)
@@ -526,7 +521,7 @@ def objective_field_names(models_or_ensembles, api):
                     try:
                         ensemble = check_resource(
                             ensemble_id, api.get_ensemble)
-                    except ValueError, exception:
+                    except ValueError as exception:
                         sys.exit("Failed to get a finished ensemble: %s" %
                                  str(exception))
                     name = objective_field_name(ensemble, api)
@@ -623,7 +618,7 @@ def get_options_list(args, options, prioritary=None):
     for option in filtered_options:
         try:
             flag = option[2:].replace("-", "_")
-            if flag in non_equivalent_options.keys():
+            if flag in list(non_equivalent_options.keys()):
                 flag = non_equivalent_options[flag]
             value = getattr(args, flag)
             if value is not None:
@@ -635,7 +630,7 @@ def get_options_list(args, options, prioritary=None):
                         options_list.append("%s=%s" %
                                             (option, ",".join(value)))
                 else:
-                    if not isinstance(value, basestring):
+                    if not isinstance(value, str):
                         value = str(value)
                     options_list.append("%s=%s" % (option, value))
         except AttributeError:
@@ -647,8 +642,8 @@ def print_generated_files(path, log_file=None, verbosity=1):
     """Prints the file structure generated while running bigmler
 
     """
-    message = (u"\nGenerated files:\n\n" +
-               print_tree(path, u" ") + u"\n")
+    message = ("\nGenerated files:\n\n" +
+               print_tree(path, " ") + "\n")
     log_message(message, log_file=log_file, console=verbosity)
 
 
@@ -679,25 +674,7 @@ def open_mode(mode):
     """Python 3 compatible open mode
 
     """
-    return "%st" % mode if PYTHON3 else "%s" % mode
-
-
-def encode2(value, encoding=FILE_ENCODING):
-    """Conditional encoding only for Python2
-
-    """
-    if isinstance(value, basestring) and not PYTHON3:
-        return value.encode(encoding)
-    return value
-
-
-def decode2(value, encoding=FILE_ENCODING):
-    """Conditional decoding only for Python2
-
-    """
-    if isinstance(value, basestring) and not PYTHON3:
-        return value.decode(encoding)
-    return value
+    return "%st" % mode
 
 
 def transform_fields_keys(json_attributes, fields):
@@ -708,8 +685,8 @@ def transform_fields_keys(json_attributes, fields):
     fields_structure = {}
     if fields is None:
         return json_attributes
-    if "fields" in json_attributes.keys():
-        old_keys = json_attributes["fields"].keys()
+    if "fields" in list(json_attributes.keys()):
+        old_keys = list(json_attributes["fields"].keys())
         for old_key in old_keys:
             try:
                 if not old_key in fields.fields:
@@ -797,12 +774,8 @@ def write_to_utf8(path, text):
     """Encoded UTF-8 text write
 
     """
-    if PYTHON3:
-        with open(path, "w", encoding="utf-8") as file_handler:
-            file_handler.write(text)
-    else:
-        with open(path, "w") as file_handler:
-            file_handler.write(text.encode("utf-8"))
+    with open(path, "w", encoding="utf-8") as file_handler:
+        file_handler.write(text)
 
 
 def has_connection_info(args):
@@ -810,7 +783,7 @@ def has_connection_info(args):
 
     """
     check = True
-    connection_env_vars = EXTERNAL_CONNECTION_ATTRS.keys()
+    connection_env_vars = list(EXTERNAL_CONNECTION_ATTRS.keys())
 
     for key in connection_env_vars:
         value = EXTERNAL_CONNECTION_ATTRS[key]
