@@ -20,7 +20,7 @@
 
 
 """
-from __future__ import absolute_import
+
 
 
 import os
@@ -42,8 +42,8 @@ COMMANDS = {"script":
                  " --store --to-library")}
 
 #subcommands
-SUBCOMMAND_LOG = u".bigmler_subcmd"
-SESSIONS_LOG = u"bigmler_sessions"
+SUBCOMMAND_LOG = ".bigmler_subcmd"
+SESSIONS_LOG = "bigmler_sessions"
 
 #name max length
 NAME_MAX_LENGTH = 127
@@ -76,9 +76,6 @@ def retrieve_subcommands():
     """
     global subcommand_list
     subcommand_list = open(subcommand_file, u.open_mode("r")).readlines()
-    if not u.PYTHON3:
-        subcommand_list = [subcommand.decode(u.SYSTEM_ENCODING)
-                           for subcommand in subcommand_list]
     subcommand_list.reverse()
 
 
@@ -86,7 +83,7 @@ def rebuild_command(args):
     """Rebuilds a unicode command string prepared to be stored in a file
 
     """
-    return "%s\n" % (u" ".join(args)).replace("\\", "\\\\")
+    return "%s\n" % (" ".join(args)).replace("\\", "\\\\")
 
 
 def different_command(next_command, command):
@@ -131,7 +128,6 @@ def create_package(args, api, command_obj, resume=False):
     file.
 
     """
-    common_options = command_obj.common_options
     set_subcommand_file(args.output_dir)
     if resume:
         retrieve_subcommands()
@@ -250,3 +246,4 @@ def create_package(args, api, command_obj, resume=False):
                 execute_dispatcher(args=command_args)
             args.output_dir = output_dir
             return whizzml_code
+    return ""
